@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: print-dialog.c,v 1.8 2003/08/08 17:31:04 chpe Exp $
+ *  $Id: print-dialog.c,v 1.9 2003/08/15 10:03:27 chpe Exp $
  */
 
 #include "print-dialog.h"
 #include "ephy-prefs.h"
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkstock.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 
 #define CONF_PRINT_BOTTOM_MARGIN "/apps/epiphany/dialogs/print_bottom_margin"
 #define CONF_PRINT_TOP_MARGIN "/apps/epiphany/dialogs/print_top_margin"
@@ -299,7 +300,7 @@ print_get_info (EphyDialog *dialog)
 	g_value_unset (&printer);
 
 	ephy_dialog_get_value (dialog, FILE_PROP, &file);
-	info->file = g_strdup (g_value_get_string (&file));
+	info->file = gnome_vfs_expand_initial_tilde (g_value_get_string (&file));
 	g_value_unset (&file);
 
 	ephy_dialog_get_value (dialog, BOTTOM_PROP, &bottom_margin);
